@@ -8,7 +8,7 @@
 #' @param pal Character vector of hex codes. 
 #' @param borders A sf object as administrative boundaries (or coastlines). Defaults to no boundaries added. The rnaturalearth package is a useful source of country and state boundaries.
 #' @param borders_behind TRUE or FALSE  as to whether the borders is to be behind the sf object defined in the data argument. Defaults to TRUE.
-#' @param borders_pal Colour of the borders. Defaults to "#7F7F7F".
+#' @param pal_borders Colour of the borders. Defaults to "#7F7F7F".
 #' @param borders_size Size of the borders. Defaults to 0.2.
 #' @param title Title string. Defaults to NULL.
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 100. Not applicable where mobile equals TRUE.
@@ -34,7 +34,7 @@ gg_sf <- function(data,
                   pal = NULL,
                   borders = NULL,
                   borders_behind = TRUE,
-                  borders_pal = "#7f7f7f",
+                  pal_borders = "#7F7F7FFF",
                   borders_size = 0.2,
                   title = NULL,
                   title_wrap = 100,
@@ -71,7 +71,7 @@ gg_sf <- function(data,
         geom_sf(
           data = borders,
           size = borders_size, 
-          colour = borders_pal,
+          colour = pal_borders,
           fill = "transparent"
         )
     }
@@ -104,7 +104,7 @@ gg_sf <- function(data,
         geom_sf(
           data = borders,
           size = borders_size, 
-          colour = borders_pal,
+          colour = pal_borders,
           fill = "transparent"
         )
     }
@@ -137,25 +137,25 @@ gg_sf <- function(data,
 #' @param col_var Unquoted variable for points to be coloured by. Required input.
 #' @param text_var Unquoted variable to be used as a customised tooltip in combination with plotly::ggplotly(plot, tooltip = "text"). Defaults to NULL.
 #' @param pal Character vector of hex codes. Defaults to NULL, which selects the colorbrewer Set1 or viridis.
+#' @param pal_na The hex code or name of the NA colour to be used.
 #' @param pal_rev Reverses the palette. Defaults to FALSE.
 #' @param size_point Size of points. Defaults to 0.5.
 #' @param size_line Size of lines. Defaults to 0.5.
 #' @param alpha The opacity of polygons. Defaults to 0.9.
 #' @param borders A sf object as administrative boundaries (or coastlines). Defaults to no boundaries added. The rnaturalearth package is a useful source of country and state boundaries.
 #' @param borders_behind TRUE or FALSE  as to whether the borders is to be behind the sf object defined in the data argument. Defaults to TRUE.
-#' @param borders_pal Colour of the borders. Defaults to "#7F7F7F".
+#' @param pal_borders Colour of the borders. Defaults to "#7F7F7F".
 #' @param borders_size Size of the borders. Defaults to 0.2.
 #' @param title Title string. Defaults to NULL.
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 100. Not applicable where mobile equals TRUE.
 #' @param subtitle Subtitle string. 
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 100. Not applicable where mobile equals TRUE.
 #' @param col_cuts A vector of cuts to colour a numeric variable. If "bin" is selected, the first number in the vector should be either -Inf or 0, and the final number Inf. If "quantile" is selected, the first number in the vector should be 0 and the final number should be 1. Defaults to quartiles. 
-#' @param col_labels A function or vector to modify colour scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case, and numeric variable labels to pretty labels with an internal function. Use ggplot2::waiver() to keep colour labels untransformed.   
-#' @param col_labels_dp For numeric colour variables and where col_labels equals NULL, the number of decimal places. Defaults to 1 for "quantile" col_method, and the lowest dp within the col_cuts vector for "bin".
-#' @param col_legend_ncol The number of columns in the legend. 
-#' @param col_legend_nrow The number of rows in the legend.
-#' @param col_method The method of colouring features, either "bin", "quantile" or "category." NULL results in "category", if categorical or "quantile" if numeric col_var. Note all numeric variables are cut to be inclusive of the min in the range, and exclusive of the max in the range (except for the final bucket which includes the highest value).
+#' @param col_labels A function or named vector to modify colour scale labels. Defaults to stringr::str_to_sentence for categorical colour variables and an internal function for numeric colour variables. Use ggplot2::waiver() to keep colour labels untransformed.  
+#' @param col_method The method of colouring features, either "bin", "quantile" or "category." If numeric, defaults to "bin".
+#' @param col_pretty_n For a numeric colour variable of "bin" col_method, the desired number of intervals on the colour scale, as calculated by the pretty algorithm. Defaults to 4. 
 #' @param col_na TRUE or FALSE of whether to include col_var NA values. Defaults to TRUE.
+#' @param col_right_closed For a numeric colour variable, TRUE or FALSE of whether bins or quantiles are to be cut right-closed. Defaults to TRUE.
 #' @param col_title Colour title string for the legend. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param col_title_wrap Number of characters to wrap the colour title to. Defaults to 25. Not applicable where mobile equals TRUE.
 #' @param caption Caption title string. 
@@ -187,13 +187,14 @@ gg_sf_col <- function(data,
                       col_var,
                       text_var = NULL,
                       pal = NULL,
+                      pal_na = "#7F7F7FFF",
                       pal_rev = FALSE,
                       size_point = 1,
                       size_line = 0.5,
                       alpha = 0.9,
                       borders = NULL,
                       borders_behind = TRUE,
-                      borders_pal = "#7f7f7f",
+                      pal_borders = "#7F7F7FFF",
                       borders_size = 0.2,
                       title = NULL,
                       title_wrap = 100,
@@ -201,11 +202,10 @@ gg_sf_col <- function(data,
                       subtitle_wrap = 100,
                       col_cuts = NULL,
                       col_labels = NULL,
-                      col_labels_dp = NULL,
-                      col_legend_ncol = NULL,
-                      col_legend_nrow = NULL,
                       col_na = TRUE,
+                      col_pretty_n = 4,
                       col_method = NULL,
+                      col_right_closed = TRUE,
                       col_title = NULL,
                       col_title_wrap = 25,
                       caption = NULL,
@@ -258,7 +258,7 @@ gg_sf_col <- function(data,
         geom_sf(
           data = borders,
           size = borders_size, 
-          colour = borders_pal,
+          colour = pal_borders,
           fill = "transparent"
         )
     }
@@ -266,7 +266,7 @@ gg_sf_col <- function(data,
   
   if (is.null(col_method)) {
     if (!is.numeric(col_var_vctr)) col_method <- "category"
-    else if (is.numeric(col_var_vctr)) col_method <- "quantile"
+    else if (is.numeric(col_var_vctr)) col_method <- "bin"
   }
   
   if(col_method %in% c("quantile", "bin")) {
@@ -278,21 +278,26 @@ gg_sf_col <- function(data,
       }  
       col_cuts <- stats::quantile(col_var_vctr, probs = col_cuts, na.rm = TRUE)
       if (anyDuplicated(col_cuts) > 0) stop("col_cuts do not provide unique breaks")
-      if(is.null(col_labels_dp)) col_labels_dp <- 1
     }
     else if (col_method == "bin") {
-      if (is.null(col_cuts)) col_cuts <- pretty(col_var_vctr)
+      if (is.null(col_cuts)) col_cuts <- pretty(col_var_vctr, col_pretty_n)
       else({
         if (!(dplyr::first(col_cuts) %in% c(0, -Inf))) warning("The first element of the col_cuts vector should generally be 0 (or -Inf if there are negative values)")
         if (dplyr::last(col_cuts) != Inf) warning("The last element of the col_cuts vector should generally be Inf")
       })
-      if(is.null(col_labels_dp)) col_labels_dp <- sv_max_dp(col_cuts)
     }
+
+    if (is.null(col_labels)) col_labels <- scales::comma
     
     data <- data %>% 
-      dplyr::mutate(dplyr::across(!!col_var, ~cut(.x, col_cuts, right = FALSE, include.lowest = TRUE)))
+      dplyr::mutate(dplyr::across(!!col_var, ~kimisc::cut_format(.x, col_cuts, 
+                                                                 right = col_right_closed, 
+                                                                 include.lowest = TRUE, 
+                                                                 dig.lab = 50, 
+                                                                 ordered_result = TRUE,
+                                                                 format_fun = col_labels)))
     
-    if(is.null(col_labels)) col_labels <- sv_numeric_bin_labels(col_cuts, col_labels_dp)
+    col_labels <- sv_interval_breaks_to_interval_labels
     
     col_n <- length(col_cuts) - 1
     if (is.null(pal)) pal <- pal_viridis_reorder(col_n)
@@ -307,7 +312,7 @@ gg_sf_col <- function(data,
     if (is.null(pal)) pal <- pal_d3_reorder(col_n)
     else pal <- pal[1:col_n]
     
-    if(is.null(col_labels)) col_labels <- function(x) stringr::str_to_sentence(x)
+    if(is.null(col_labels)) col_labels <- stringr::str_to_sentence
   }
   
   if (pal_rev == TRUE) pal <- rev(pal)
@@ -338,12 +343,15 @@ gg_sf_col <- function(data,
       )
   }
   
+  if (mobile == TRUE) col_title_wrap <- 20
+
   plot <- plot +
-    scale_color_manual(
+    scale_colour_manual(
       values = pal,
       drop = FALSE,
       labels = col_labels,
-      na.value = pal_na()
+      na.value = pal_na,
+      name = stringr::str_wrap(col_title, col_title_wrap)
     )
   
     if (geometry_type %in% c("POLYGON", "MULTIPOLYGON")) {
@@ -352,7 +360,8 @@ gg_sf_col <- function(data,
         values = pal,
         drop = FALSE,
         labels = col_labels,
-        na.value = pal_na()
+        na.value = pal_na,
+        name = stringr::str_wrap(col_title, col_title_wrap)
       )
   }
   
@@ -362,7 +371,7 @@ gg_sf_col <- function(data,
         geom_sf(
           data = borders,
           size = borders_size, 
-          colour = borders_pal,
+          colour = pal_borders,
           fill = "transparent"
         )
     }
@@ -375,8 +384,8 @@ gg_sf_col <- function(data,
         subtitle = stringr::str_wrap(subtitle, subtitle_wrap),
         caption = stringr::str_wrap(caption, caption_wrap)
       ) +
-      guides(col = guide_legend(ncol = col_legend_ncol, nrow = col_legend_nrow, byrow = TRUE, title = stringr::str_wrap(col_title, col_title_wrap))) +
-      guides(fill = guide_legend(ncol = col_legend_ncol, nrow = col_legend_nrow, byrow = TRUE, title = stringr::str_wrap(col_title, col_title_wrap)))
+      guides(col = guide_legend(byrow = TRUE)) +
+      guides(fill = guide_legend(byrow = TRUE))
   }
   else if (mobile == TRUE) {
     plot <- plot +
@@ -385,8 +394,8 @@ gg_sf_col <- function(data,
         subtitle = stringr::str_wrap(subtitle, 40),
         caption = stringr::str_wrap(caption, 50)
       )  +
-      guides(col = guide_legend(ncol = 1, byrow = TRUE, title = stringr::str_wrap(col_title, 20))) +
-      guides(col = guide_legend(ncol = 1, byrow = TRUE, title = stringr::str_wrap(col_title, 20))) +
+      guides(col = guide_legend(ncol = 1)) +
+      guides(col = guide_legend(ncol = 1)) +
       theme_mobile_extra_map()
   }
   
@@ -402,13 +411,13 @@ gg_sf_col <- function(data,
 #' @param size_line Size of lines. Defaults to 0.5.
 #' @param alpha The alpha of the fill. Defaults to 0.9. 
 #' @param pal Character vector of hex codes. 
-#' @param facet_labels As per the ggplot2 labeller argument within the ggplot facet_wrap function. If NULL, defaults to ggplot2::as_labeller(stringr::str_to_sentence). Use facet_labels = ggplot2::label_value to turn off default sentence case transformation.
+#' @param facet_labels A function or named vector to modify facet scale labels. Defaults to converting labels to sentence case. Use ggplot2::waiver() to keep facet labels untransformed.
 #' @param facet_na TRUE or FALSE of whether to include facet_var NA values. Defaults to TRUE.
 #' @param facet_ncol The number of columns of facetted plots. 
 #' @param facet_nrow The number of rows of facetted plots. 
 #' @param borders A sf object as administrative boundaries (or coastlines). Defaults to no boundaries added. The rnaturalearth package is a useful source of country and state boundaries.
 #' @param borders_behind TRUE or FALSE  as to whether the borders is to be behind the sf object defined in the data argument. Defaults to TRUE.
-#' @param borders_pal Colour of the borders. Defaults to "#7F7F7F".
+#' @param pal_borders Colour of the borders. Defaults to "#7F7F7F".
 #' @param borders_size Size of the borders. Defaults to 0.2.
 #' @param title Title string. Defaults to NULL.
 #' @param subtitle Subtitle string. 
@@ -433,13 +442,13 @@ gg_sf_facet <- function(data,
                         size_line = 0.5,
                         alpha = 0.9,
                         pal = NULL,
-                        facet_labels = NULL,
+                        facet_labels = stringr::str_to_sentence,
                         facet_na = TRUE,
                         facet_ncol = NULL,
                         facet_nrow = NULL,
                         borders = NULL,
                         borders_behind = TRUE,
-                        borders_pal = "#7f7f7f",
+                        pal_borders = "#7F7F7FFF",
                         borders_size = 0.2,
                         title = NULL,
                         title_wrap = 100,
@@ -494,7 +503,7 @@ gg_sf_facet <- function(data,
         geom_sf(
           data = borders,
           size = borders_size, 
-          colour = borders_pal,
+          colour = pal_borders,
           fill = "transparent"
         )
     }
@@ -539,21 +548,19 @@ gg_sf_facet <- function(data,
         geom_sf(
           data = borders,
           size = borders_size, 
-          colour = borders_pal,
+          colour = pal_borders,
           fill = "transparent"
         )
     }
   }
   
-  if(is.null(facet_labels)) facet_labels <- as_labeller(stringr::str_to_sentence)
-  
   plot <- plot +
     labs(
       title = stringr::str_wrap(title, title_wrap),
       subtitle = stringr::str_wrap(subtitle, subtitle_wrap),
       caption = stringr::str_wrap(caption, 50)
     ) +
-    facet_wrap(vars(!!facet_var), labeller = facet_labels, scales = "fixed", ncol = facet_ncol, nrow = facet_nrow)
+    facet_wrap(vars(!!facet_var), labeller = as_labeller(facet_labels), scales = "fixed", ncol = facet_ncol, nrow = facet_nrow)
 
   return(plot)
 }
@@ -565,26 +572,26 @@ gg_sf_facet <- function(data,
 #' @param facet_var Unquoted categorical variable to facet the data by. Required input.
 #' @param text_var Unquoted variable to be used as a customised tooltip in combination with plotly::ggplotly(plot, tooltip = "text"). Defaults to NULL.
 #' @param pal Character vector of hex codes. Defaults to NULL, which selects the colorbrewer Set1 or viridis.
+#' @param pal_borders Colour of the borders. Defaults to "#7F7F7F".
+#' @param pal_na The hex code or name of the NA colour to be used.
 #' @param pal_rev Reverses the palette. Defaults to FALSE.
 #' @param size_point Size of points. Defaults to 0.5.
 #' @param size_line Size of lines. Defaults to 0.5.
 #' @param alpha The opacity of polygons. Defaults to 0.9.
 #' @param borders A sf object as administrative boundaries (or coastlines). Defaults to no boundaries added. The rnaturalearth package is a useful source of country and state boundaries.
 #' @param borders_behind TRUE or FALSE  as to whether the borders is to be behind the sf object defined in the data argument. Defaults to TRUE.
-#' @param borders_pal Colour of the borders. Defaults to "#7F7F7F".
 #' @param borders_size Size of the borders. Defaults to 0.2.
 #' @param title Title string. Defaults to NULL.
 #' @param title_wrap Number of characters to wrap the title to. Defaults to 100. 
 #' @param subtitle Subtitle string. 
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 100. 
 #' @param col_cuts A vector of cuts to colour a numeric variable. If "bin" is selected, the first number in the vector should be either -Inf or 0, and the final number Inf. If "quantile" is selected, the first number in the vector should be 0 and the final number should be 1. Defaults to quartiles. 
-#' @param facet_labels As per the ggplot2 labeller argument within the ggplot facet_wrap function. If NULL, defaults to ggplot2::as_labeller(stringr::str_to_sentence). Use facet_labels = ggplot2::label_value to turn off default sentence case transformation.
-#' @param col_labels A function or vector to modify colour scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case, and numeric variable labels to pretty labels with an internal function. Use ggplot2::waiver() to keep colour labels untransformed.   
-#' @param col_labels_dp For numeric colour variables and where col_labels equals NULL, the number of decimal places. Defaults to 1 for "quantile" col_method, and the lowest dp within the col_cuts vector for "bin".
-#' @param col_legend_ncol The number of columns in the legend. 
-#' @param col_legend_nrow The number of rows in the legend.
-#' @param col_method The method of colouring features, either "bin", "quantile" or "category." NULL results in "category", if categorical or "quantile" if numeric col_var. Note all numeric variables are cut to be inclusive of the min in the range, and exclusive of the max in the range (except for the final bucket which includes the highest value).
+#' @param facet_labels A function or named vector to modify facet scale labels. Defaults to converting labels to sentence case. Use ggplot2::waiver() to keep facet labels untransformed.
+#' @param col_labels A function or named vector to modify colour scale labels. Defaults to stringr::str_to_sentence for categorical colour variables and an internal function for numeric colour variables. Use ggplot2::waiver() to keep colour labels untransformed.  
+#' @param col_method The method of colouring features, either "bin", "quantile" or "category." If numeric, defaults to "bin".
+#' @param col_pretty_n For a numeric colour variable of "bin" col_method, the desired number of intervals on the colour scale, as calculated by the pretty algorithm. Defaults to 4. 
 #' @param col_na TRUE or FALSE of whether to include col_var NA values. Defaults to TRUE.
+#' @param col_right_closed For a numeric colour variable, TRUE or FALSE of whether bins or quantiles are to be cut right-closed. Defaults to TRUE.
 #' @param col_title Colour title string for the legend. Defaults to NULL, which converts to sentence case with spaces. Use "" if you would like no title.
 #' @param col_title_wrap Number of characters to wrap the colour title to. Defaults to 25. 
 #' @param facet_na TRUE or FALSE of whether to include facet_var NA values. Defaults to TRUE.
@@ -608,13 +615,14 @@ gg_sf_col_facet <- function(data,
                             facet_var,
                             text_var = NULL,
                             pal = NULL,
+                            pal_borders = "#7F7F7FFF",
+                            pal_na = "#7F7F7FFF",
                             pal_rev = FALSE,
                             size_point = 1,
                             size_line = 0.5,
                             alpha = 0.9,
                             borders = NULL,
                             borders_behind = TRUE,
-                            borders_pal = "#7f7f7f",
                             borders_size = 0.2,
                             title = NULL,
                             title_wrap = 100,
@@ -622,14 +630,13 @@ gg_sf_col_facet <- function(data,
                             subtitle_wrap = 100,
                             col_cuts = NULL,
                             col_labels = NULL,
-                            col_labels_dp = NULL,
                             col_method = NULL,
-                            col_legend_ncol = NULL,
-                            col_legend_nrow = NULL,
                             col_na = TRUE,
+                            col_pretty_n = 4,
+                            col_right_closed = TRUE,
                             col_title = NULL,
                             col_title_wrap = 25,
-                            facet_labels = NULL,
+                            facet_labels = stringr::str_to_sentence,
                             facet_na = TRUE,
                             facet_ncol = NULL,
                             facet_nrow = NULL,
@@ -695,7 +702,7 @@ gg_sf_col_facet <- function(data,
         geom_sf(
           data = borders,
           size = borders_size, 
-          colour = borders_pal,
+          colour = pal_borders,
           fill = "transparent"
         )
     }
@@ -703,7 +710,7 @@ gg_sf_col_facet <- function(data,
   
   if (is.null(col_method)) {
     if (!is.numeric(col_var_vctr)) col_method <- "category"
-    else if (is.numeric(col_var_vctr)) col_method <- "quantile"
+    else if (is.numeric(col_var_vctr)) col_method <- "bin"
   }
   
   if(col_method %in% c("quantile", "bin")) {
@@ -715,21 +722,26 @@ gg_sf_col_facet <- function(data,
       }  
       col_cuts <- stats::quantile(col_var_vctr, probs = col_cuts, na.rm = TRUE)
       if (anyDuplicated(col_cuts) > 0) stop("col_cuts do not provide unique breaks")
-      if(is.null(col_labels_dp)) col_labels_dp <- 1
     }
     else if (col_method == "bin") {
-      if (is.null(col_cuts)) col_cuts <- pretty(col_var_vctr)
+      if (is.null(col_cuts)) col_cuts <- pretty(col_var_vctr, col_pretty_n)
       else({
         if (!(dplyr::first(col_cuts) %in% c(0, -Inf))) warning("The first element of the col_cuts vector should generally be 0 (or -Inf if there are negative values)")
         if (dplyr::last(col_cuts) != Inf) warning("The last element of the col_cuts vector should generally be Inf")
       })
-      if(is.null(col_labels_dp)) col_labels_dp <- sv_max_dp(col_cuts)
     }
+
+    if (is.null(col_labels)) col_labels <- scales::comma
     
     data <- data %>% 
-      dplyr::mutate(dplyr::across(!!col_var, ~cut(.x, col_cuts, right = FALSE, include.lowest = TRUE)))
+      dplyr::mutate(dplyr::across(!!col_var, ~kimisc::cut_format(.x, col_cuts, 
+                                                                 right = col_right_closed, 
+                                                                 include.lowest = TRUE, 
+                                                                 dig.lab = 50, 
+                                                                 ordered_result = TRUE,
+                                                                 format_fun = col_labels)))
     
-    if(is.null(col_labels)) col_labels <- sv_numeric_bin_labels(col_cuts, col_labels_dp)
+    col_labels <- sv_interval_breaks_to_interval_labels
     
     col_n <- length(col_cuts) - 1
     if (is.null(pal)) pal <- pal_viridis_reorder(col_n)
@@ -744,7 +756,7 @@ gg_sf_col_facet <- function(data,
     if (is.null(pal)) pal <- pal_d3_reorder(col_n)
     else pal <- pal[1:col_n]
     
-    if(is.null(col_labels)) col_labels <- function(x) stringr::str_to_sentence(x)
+    if(is.null(col_labels)) col_labels <- stringr::str_to_sentence
   }
   
   if (pal_rev == TRUE) pal <- rev(pal)
@@ -776,11 +788,12 @@ gg_sf_col_facet <- function(data,
   }
   
   plot <- plot +
-    scale_color_manual(
+    scale_colour_manual(
       values = pal,
       drop = FALSE,
       labels = col_labels,
-      na.value = pal_na()
+      na.value = pal_na,
+      name = stringr::str_wrap(col_title, col_title_wrap)
     )
   
   if (geometry_type %in% c("POLYGON", "MULTIPOLYGON")) {
@@ -789,7 +802,8 @@ gg_sf_col_facet <- function(data,
         values = pal,
         drop = FALSE,
         labels = col_labels,
-        na.value = pal_na()
+        na.value = pal_na,
+        name = stringr::str_wrap(col_title, col_title_wrap)
       )
   }
   
@@ -799,24 +813,21 @@ gg_sf_col_facet <- function(data,
         geom_sf(
           data = borders,
           size = borders_size, 
-          colour = borders_pal,
+          colour = pal_borders,
           fill = "transparent"
         )
     }
   }
   
-  if(is.null(facet_labels)) facet_labels <- as_labeller(stringr::str_to_sentence)
-  
   plot <- plot +
     labs(
       title = stringr::str_wrap(title, title_wrap),
       subtitle = stringr::str_wrap(subtitle, subtitle_wrap),
       caption = stringr::str_wrap(caption, caption_wrap)
     ) +
-    guides(col = guide_legend(ncol = col_legend_ncol, nrow = col_legend_nrow, byrow = TRUE, title = stringr::str_wrap(col_title, col_title_wrap))) +
-    guides(fill = guide_legend(ncol = col_legend_ncol, nrow = col_legend_nrow, byrow = TRUE, title = stringr::str_wrap(col_title, col_title_wrap))) +
-    facet_wrap(vars(!!facet_var), labeller = facet_labels, scales = "fixed", ncol = facet_ncol, nrow = facet_nrow)
-  
-  
+    guides(col = guide_legend(byrow = TRUE)) +
+    guides(fill = guide_legend(byrow = TRUE)) +
+    facet_wrap(vars(!!facet_var), labeller = as_labeller(facet_labels), scales = "fixed", ncol = facet_ncol, nrow = facet_nrow)
+
   return(plot)
 }
